/*
 * gexiv2-startup.h
 *
 * Author(s)
 *  Clint Rogers <clinton@yorba.org>
 *
 * This is free software. See COPYING for details.
 */

#ifndef __GEXIV2_STARTUP_H__
#define __GEXIV2_STARTUP_H__

#include <glib-object.h>

G_BEGIN_DECLS

gboolean gexiv2_initialize(void);

G_END_DECLS
#endif
